@@ -8,15 +8,11 @@ use swc_ecma_utils::{ExprExt, Type, Value};
 use super::Pure;
 use crate::{
     compress::util::{is_pure_undefined, negate, negate_cost},
-    mode::Mode,
     option::CompressOptions,
     util::make_bool,
 };
 
-impl<M> Pure<'_, M>
-where
-    M: Mode,
-{
+impl Pure<'_> {
     pub(super) fn negate_twice(&mut self, e: &mut Expr, is_ret_val_ignored: bool) {
         negate(e, false, is_ret_val_ignored);
         negate(e, false, is_ret_val_ignored);
