@@ -12,6 +12,7 @@
 //! them something other. Don't call methods like `visit_mut_script` nor
 //! `visit_mut_module_items`.
 #![deny(clippy::all)]
+#![deny(unused)]
 #![allow(clippy::blocks_in_if_conditions)]
 #![allow(clippy::collapsible_else_if)]
 #![allow(clippy::collapsible_if)]
@@ -20,6 +21,7 @@
 #![allow(unstable_name_collisions)]
 
 use compress::pure_optimizer;
+use mode::Mode;
 use swc_common::{comments::Comments, pass::Repeat, sync::Lrc, SourceMap, SyntaxContext, GLOBALS};
 use swc_ecma_ast::Module;
 use swc_ecma_visit::{FoldWith, VisitMutWith};
@@ -140,7 +142,7 @@ pub fn optimize(
         m.visit_mut_with(&mut Repeat::new(pure_optimizer(
             options,
             marks,
-            &Minification,
+            Minification::force_str_for_tpl(),
             true,
             false,
         )));
